#ifndef SRC_CREDENTIALS_H_
#define SRC_CREDENTIALS_H_

#include <string>
#include <utility>

namespace keytar {

typedef std::pair<std::string, std::string> Credentials;

}

#endif  // SRC_CREDENTIALS_H_
